==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/client/inc/obj_listbox.js <==
_me = obj_listbox.prototype;
function obj_listbox(){};

	_me.__constructor = function(){
	    this.__idTable = {};
	    this.__value = {};
		this.__multi = true;
		this.__disabled = false;
		
		/* set whole object unselectable for Mozilla, KHTML, MSIE */
		try{ this._main.style.MozUserSelect = "none"; }catch(err){}
		try{ this._main.style.KhtmlUserSelect = "none"; }catch(err){}
		try{ this._main.element.unselectable = "on"; }catch(err){}
		
		var me = this;
		
		this._main.onclick = function(e){
			if(me.__disabled) return false;

			var e = e || window.event;
			var elm = e.target || e.srcElement;

			if (elm.tagName != 'DIV' || elm==this) return;

			var id = elm.getAttribute('id').substr(me._pathName.length);

			var etmp;
			
			/* multiselect */
			if (me.__multi && e.ctrlKey){
				//activate
				if (typeof me.__value[id] == 'undefined'){
				    me.__value[id] = elm.getAttribute('id');
					addcss(elm,'obj_listboxactive');
				}
				//deactivate
				else{
				    delete me.__value[id];
				    removecss(elm,'obj_listboxactive');
				}
			}
            /* singleselect */
			else{
				for (var j in me.__value){
					 if (j != id){
                         if ((etmp = document.getElementById(me.__value[j]))) removecss(etmp,'obj_listboxactive');
                         delete me.__value[j];
					 }
				}
				me.__value[id] = elm.getAttribute('id');
				addcss(elm,'obj_listboxactive');
			}

			if (me._onclick) me._onclick(e);
			me.__exeEvent('onclick',e,{"owner":me});
		};

		this._main.ondblclick = function(e){
			var e = e || window.event;
			var elm = e.target || e.srcElement;

			if (elm.tagName != 'DIV' || elm==this) return;

            var id = elm.getAttribute('id').substr(me._pathName.length);

			if (me._ondblclick) me._ondblclick(e,id,me.__value[id]);
			me.__exeEvent('ondblclick',e,{"owner":me,"src":id,"value":me.__value[id]});
		};
		//DEBUG
		/*
		this._disabled(true);
		this._fill({"pes":"Pes","les":"Les","kos":"Kos","brabenec":"Ferda"});
		*/
	};

	_me._multiple = function(b){
		if(typeof b == 'undefined') return this.__multi;
		
		b = b?true:false;
		
		// M->S, leave only first selected item
		if  (!b && count(this.__value)){
			var etmp,first = true;
			for (var i in this.__value){
				if  ((etmp = document.getElementById(this.__value[i]))){
					if (first){ first = false; continue; }
					removecss(etmp,'obj_listboxactive');
					delete this.__value[i];
				}
			}
		}

		this.__multi = b;
	};
	
	_me._selected = function(v) {
	    //return
		if (typeof v == 'undefined'){
			var out = [];
			for (var i in this.__value){
				out.push(i);
				if (!this.__multi) break;
			}
			return out;
		}
		//set
		else{
			if (!Is.Object(v)) v = [v];

			var etmp,id;
			for (var i in this.__value)
                if ((etmp = document.getElementById(this._pathName+i))) removecss(etmp,'obj_listboxactive');

			this.__value = [];

			for (var i in v){
				if (typeof this.__idTable[v[i]] == 'undefined') continue;

				id = this._pathName + v[i];
				this.__value[v[i]] = id;

				if ((etmp = document.getElementById(id))) addcss(etmp,'obj_listboxactive');
			}
  		}
	}

	_me._value = function(v){
		return this._selected(v);
	};
	
	_me._fill = function(aData){
		var tmp,id;

		this._main.innerHTML = '';
  		this.__idTable = {};

		for (var i in aData){
			id  = this._pathName + i;
			tmp = mkElement('div');
			addcss(tmp,'obj_listboxrow');
			tmp.setAttribute('id',id);
			tmp.innerHTML = aData[i].entityify();

            this.__idTable[i] = aData[i];
            
			this._main.appendChild(tmp);
		}
		var value = this._selected();
		if (value) this._selected(value);
	};
	
	_me._disabled = function(b){
		this.__disabled = (b?true:false);

		if (this.__disabled)
			addcss(this._main,'obj_listboxdisabled');
		else
			removecss(this._main,'obj_listboxdisabled');
	};

	_me.__update = function (sDataSet){
		if (!sDataSet) return;

		if (this._listener == sDataSet)
			this._value(dataSet.get(this._listener,this._listenerPath));
		else
		if (this._listener_data == sDataSet)
		    this._fill(dataSet.get(this._listener_data,this._listenerPath_data));
	};

	_me._listen_data = function(sDataSet,aDataPath){
		this._listener_data = sDataSet;
		if (typeof aDataPath == 'object') this._listenerPath_data = aDataPath;
		dataSet.obey(this,'_listener_data',sDataSet);
	};

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/client/inc/obj_listbox.js <==
_me = obj_listbox.prototype;
function obj_listbox(){};

	_me.__constructor = function(){
		this.__idTable = {};
		this.__value = {};
		this.__multi = true;
		this.__disabled = false;

		/* set whole object unselectable for Mozilla, Safari, KHTML, MSIE */
        setSelectNone(this._main);

		var me = this;

		this._main.onclick = function(e){
			if(me.__disabled) return false;

			var e = e || window.event;
			var elm = e.target || e.srcElement;

			if (elm.tagName != 'DIV' || elm==this) return;

			var id = elm.getAttribute('id').substr(me._pathName.length);

			var etmp;

			/* multiselect */
			if (me.__multi && e.ctrlKey){
				//activate
				if (typeof me.__value[id] == 'undefined'){
					me.__value[id] = elm.getAttribute('id');
					addcss(elm,'obj_listboxactive');
				}
				//deactivate
				else{
					delete me.__value[id];
					removecss(elm,'obj_listboxactive');
				}
			}
			/* singleselect */
			else{
				for (var j in me.__value){
					 if (j != id){
						if ((etmp = document.getElementById(me.__value[j])))
							removecss(etmp,'obj_listboxactive');

						delete me.__value[j];
					 }
				}
				me.__value[id] = elm.getAttribute('id');
				addcss(elm,'obj_listboxactive');
			}

			if (me._onclick) me._onclick(e);
			me.__exeEvent('onclick',e,{"owner":me});
		};

		this._main.ondblclick = function(e){
			var e = e || window.event;
			var elm = e.target || e.srcElement;

			if (elm.tagName != 'DIV' || elm==this) return;

			var id = elm.getAttribute('id').substr(me._pathName.length);

			if (me._ondblclick) me._ondblclick(e,id,me.__value[id]);
			me.__exeEvent('ondblclick',e,{"owner":me,"src":id,"value":me.__value[id]});
		};
		//DEBUG
		/*
		this._disabled(true);
		this._fill({"pes":"Pes","les":"Les","kos":"Kos","brabenec":"Ferda"});
		*/
	};

	_me._multiple = function(b){
		if(typeof b == 'undefined') return this.__multi;
		
		b = b?true:false;
		
		// M->S, leave only first selected item
		if  (!b && count(this.__value)){
			var etmp,first = true;
			for (var i in this.__value){
				if  ((etmp = document.getElementById(this.__value[i]))){
					if (first){ first = false; continue; }
					removecss(etmp,'obj_listboxactive');
					delete this.__value[i];
				}
			}
		}

		this.__multi = b;
	};
	
	_me._selected = function(v) {
		//return
		if (typeof v == 'undefined'){
			var out = [];
			for (var i in this.__value){
				out.push(i);
				if (!this.__multi) break;
			}
			return out;
		}
		//set
		else{
			if (!Is.Object(v)) v = [v];

			var etmp,id;
			for (var i in this.__value)
				if ((etmp = document.getElementById(this._pathName+i))) removecss(etmp,'obj_listboxactive');

			this.__value = [];

			for (var i in v){
				if (typeof this.__idTable[v[i]] == 'undefined') continue;

				id = this._pathName + v[i];
				this.__value[v[i]] = id;

				if ((etmp = document.getElementById(id))) addcss(etmp,'obj_listboxactive');
			}
		}
	}

	_me._value = function(v){
		return this._selected(v);
	};

	_me._fill = function(aData){
		var tmp,id;

		this._main.innerHTML = '';
		this.__idTable = {};

		for (var i in aData){
			id  = this._pathName + i;
			tmp = mkElement('div');
			addcss(tmp,'obj_listboxrow');
			tmp.setAttribute('id',id);
			tmp.innerHTML = aData[i].entityify();

			this.__idTable[i] = aData[i];

			this._main.appendChild(tmp);
		}
		var value = this._selected();
		if (value) this._selected(value);
	};

	_me._disabled = function(b){
		this.__disabled = (b?true:false);

		if (this.__disabled)
			addcss(this._main,'obj_listboxdisabled');
		else
			removecss(this._main,'obj_listboxdisabled');
	};

	_me.__update = function (sDataSet){
		if (!sDataSet) return;

		if (this._listener == sDataSet)
			this._value(dataSet.get(this._listener,this._listenerPath));
		else
		if (this._listener_data == sDataSet)
			this._fill(dataSet.get(this._listener_data,this._listenerPath_data));
	};

	_me._listen_data = function(sDataSet,aDataPath){
		this._listener_data = sDataSet;
		if (typeof aDataPath == 'object') this._listenerPath_data = aDataPath;
		dataSet.obey(this,'_listener_data',sDataSet);
	};
